from gameweapons import *
from gameships import *

import util

class Player:
	_oreVal = 0
	_mineralVal = 0
	_waterVal = 0
	_fuelVal = 0

	cash = 0
	currentSystem = ""

	maxItemTypes = {Weapon:2, MainThruster:1, AuxThruster:1, BowThruster:1}
	shipType = ShipBug2
	equipment = [ MainThruster, BowThruster, AuxThruster ]


	def __init__(self):
		self.visitedPlanets = {}
		pass
				
	def canAddItem(self, itemClass):
		parents = util.getParentClasses(itemClass)
		type = None
		for t in self.maxItemTypes:
			for p in parents:
				if p==t: type = t
		if type==None: return False
		total = 0
		for i in self.equipment:
			if i==type: total += 1
		return total < self.maxItemTypes[type]
	
	def addItem(self, itemClass):
		self.equipment.append(itemClass)
	
	def removeItem(selfself, itemClass):
		self.equipment.remove(itemClass)

	# return true if player has the item
	def hasItem(self, itemClass):
		try:
			self.equipment.index(itemClass)
			return True
		except ValueError:
			return False
	
	# adds ore to the hold if there is space
	def addOre(self, amt):
		if self.checkSpace(amt):
			self._oreVal += amt
		
	# adds mineral to the hold if there is space
	def addMineral(self, amt):
		if self.checkSpace(amt):
			self._mineralVal += amt
	
	# adds water to the hold if there is space
	def addWater(self, amt):
		if self.checkSpace(amt):
			self._waterVal += amt
			
	# adds fuel to the hold if there is space		
	def addFuel(self, amt):
		if self.checkSpace(amt):
			self._fuelVal += amt
			
	def addCash(self, amt):
		self.cash += amt
	
	# removes resources from the hold
			
	def removeOre(self, amt):
		self._oreVal -= amt
		
	def removeMineral(self, amt):
		self._mineralVal -= amt
	
	def removeWater(self, amt):
		self._waterVal -= amt
			
	def removeFuel(self, amt):
		self._fuelVal -= amt

	def removeCash(self, amt):
		self.cash -= amt

	def getOre(self): return self._oreVal
	def getMineral(self): return self._mineralVal
	def getWater(self): return self._waterVal
	def getFuel(self): return self._fuelVal
			
	def setOre(self, amt): self._oreVal = amt
	def setMineral(self, amt): self._mineralVal = amt
	def setWater(self, amt): self._waterVal = amt
	def setFuel(self, amt): self._fuelVal = amt
	
	def getTotalCargo(self):
		return (self._mineralVal + self._waterVal + self._oreVal + self._fuelVal)
		
	# returns true if there is enough hull space to add this amount
	def checkSpace(self, amt):
		return (self.getTotalCargo() + amt) <= self.shipType.hullSpace
	
	# returns the amount of hull space left
	def getHullSpaceLeft(self):
		return self.shipType.hullSpace - self.getTotalCargo()
